﻿using Spider.Infrastructure;
using System.Collections.Generic;
using System.Reflection;

namespace Spider.Core.Caching
{
    /// <summary>
    /// 实现针对方法返回值的缓存
    /// </summary>
    public class CacheKey
    {
        public MethodBase Method { get; }
        public object[] InputArguments { get; }

        public CacheKey(MethodBase method, object[] arguments)
        {
            this.Method = method;
            this.InputArguments = arguments;
        }

        public override int GetHashCode()
        {
            var objs = new List<object> { Method };
            objs.AddRange(InputArguments);
            return HashCodeHelper.CombineHashCodes(objs);
        }

        public override bool Equals(object obj)
        {
            if (ReferenceEquals(this, obj)) return true;
            if (ReferenceEquals(null, obj)) return false;

            return obj is CacheKey other && GetHashCode() == other.GetHashCode();
        }
    }
}
