﻿namespace Spider.Core
{
    public class DataCollectContext
    {
        /// <summary>
        /// 处理检查点
        /// </summary>
        public int CheckPointId { get; set; }

        /// <summary>
        /// 用户检查点
        /// </summary>
        public int UserCheckPointId { get; set; }

        /// <summary>
        /// 总处理数量
        /// </summary>
        public int TotalSizeProcessed { get; set; }

        /// <summary>
        /// 大批次：第几轮
        /// </summary>
        /// <remarks>每个大批次启动一个WebDriver。</remarks>
        public int LargeBatch { get; set; } = 1;

        /// <summary>
        /// 大批次数量
        /// </summary>
        public int LargeBatchSize { get; set; }

        /// <summary>
        /// 小批次：第几轮
        /// </summary>
        public int SmallBatch { get; set; } = 1;

        /// <summary>
        /// 小批次数量
        /// </summary>
        public int SmallBatchSize { get; set; } = 100;

        /// <summary>
        /// 总轮数
        /// </summary>
        public int Rounds => TotalSizeProcessed % LargeBatchSize == 0 ? TotalSizeProcessed / LargeBatchSize : (TotalSizeProcessed / LargeBatchSize) + 1;

        public override string ToString()
        {
            return $"{{CheckPointId:{CheckPointId},TotalSizeProcessed:{TotalSizeProcessed}, LargeBatch:{LargeBatch}, LargeBatchSize:{LargeBatchSize}, SmallBatch:{SmallBatch}, SmallBatchSize:{SmallBatchSize}, Rounds:{Rounds}}}";
        }

        public DataCollectContext Clone()
        {
            return new DataCollectContext()
            {
                LargeBatch = this.LargeBatch,
                LargeBatchSize = this.LargeBatchSize,
                SmallBatch = this.SmallBatch,
                SmallBatchSize = this.SmallBatchSize,
                TotalSizeProcessed = this.TotalSizeProcessed,
                CheckPointId = this.CheckPointId
            };
        }
    }
}
