﻿namespace Spider.Core
{
    public class DataCollectorOptions
    {
        /// <summary>
        /// 目标地址
        /// </summary>
        public string TargetUrl { get; set; }

        /// <summary>
        /// 处理因子：批次数/总处理数，范围：(0 - 1]
        /// </summary>
        /// <remarks>
        /// 1：表示不分批次，串行处理所有商品。
        /// 0.5：分2个大批次并行处理商品。
        /// 0.2：分5个大批次并行处理商品。
        /// 以此类推...
        /// 不能整除的情况下，将会多增加一个大批次。
        /// </remarks>
        public float ProcessFactor { get; set; }

        /// <summary>
        /// 从检查点开始处理
        /// </summary>
        /// <remarks>
        /// 不设置：从第一个标识开始处理。
        /// 设置：查看日志，手工设置进度检查点。
        /// </remarks>
        public int CheckPointId { get; set; }

        /// <summary>
        /// 搜索结果下标
        /// </summary>
        /// <remarks>
        /// 选择爬取搜索结果的第几个商品，默认爬取第一个。
        /// </remarks>
        public int SearchResultIndex { get; set; } = 1;

        /// <summary>
        /// 搜索超时，单位：秒，默认：10s。
        /// </summary>
        public int SearchTimeOutSeconds { get; set; } = 10;

        public override string ToString()
        {
            return $"{{TargetUrl: {TargetUrl},ProcessFactor: {ProcessFactor}}}";
        }
    }
}
