﻿using Spider.Core.DataProvider;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Spider.Core.Pipeline
{
    public class Transformer : ITransformable
    {
        private static readonly Random Random = new Random();

        private readonly IDataProvider<User> _dataProvider;

        public Transformer(IDataProvider<User> dataProvider)
        {
            _dataProvider = dataProvider;
        }

        /// <summary>
        /// 补全、转换、清洗数据
        /// </summary>
        public async Task TransformAsync(
            DataCollectContext context,
            IEnumerable<PayLoad> payLoads)
        {
            if (context == null ||
                payLoads == null ||
                !payLoads.Any())
                return;

            var batchSize = context.SmallBatchSize;
            context.UserCheckPointId = await _dataProvider.GetCheckPointIdAsync();
            var users = (await _dataProvider.GetAsync(context)).ToArray();

            foreach (var payLoad in payLoads)
            {
                var index = Random.Next(0, batchSize);
                var hours = Random.Next(1, 24);
                payLoad.Question.QuestionerId = users[index].Id;
                // 如果后台取的用户名为空，则使用爬取的用户名。
                var name = users[index].Name;
                payLoad.Question.QuestionerName = string.IsNullOrEmpty(name) ? payLoad.Question.QuestionerName : name;
                payLoad.Question.QuestionerAvatar = users[index].Avatar;
                payLoad.Question.CreateTime = DateTime.Now.AddHours(hours);

                // 随机审核
                if (hours % 2 == 0)
                {
                    payLoad.Question.IsAudited = true;
                    payLoad.Question.AuditTime = DateTime.Now.AddHours(hours + 24);
                }

                if (payLoad.Answer == null) continue;
                // 增加回答数
                payLoad.Question.AnswerCount = 1;

                index = Random.Next(1, batchSize);
                hours = Random.Next(48, 100);
                payLoad.Answer.AnswererId = users[index].Id;
                payLoad.Answer.AnswererName = users[index]?.Name;
                payLoad.Answer.AnswererAvatar = users[index].Avatar;
                payLoad.Answer.IsBest = hours % 2 == 0; // 随机设置最佳答案
                payLoad.Answer.CreateTime = DateTime.Now.AddHours(hours);
            }
        }
    }
}
