﻿using Microsoft.Extensions.Options;
using MySql.Data.MySqlClient;
using NPoco;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Spider.Core.Pipeline
{
    public class Loader : ILoadable
    {
        private readonly MySqlOptions _options;

        public Loader(IOptions<MySqlOptions> options)
        {
            _options = options.Value;
        }

        public async Task LoadAsync(IEnumerable<PayLoad> payloads)
        {
            if (payloads == null ||
                !payloads.Any())
                return;

            using (var db = new Database(_options.ConnectionString, DatabaseType.MySQL, new MySqlClientFactory()))
            using (var trans = db.GetTransaction())
            {
                foreach (var payLoad in payloads)
                {
                    if (payLoad.Question == null) continue;
                    var result = await db.InsertAsync(payLoad.Question);

                    if (payLoad.Answer == null ||
                        !int.TryParse(result?.ToString(), out var questionId))
                        continue;
                    payLoad.Answer.QuestionId = questionId;
                    await db.InsertAsync(payLoad.Answer);
                }

                trans.Complete();
            }
        }
    }
}
