﻿using NPoco;

namespace Spider.Infrastructure.Pos
{
    /// <summary>
    /// 问题回答表
    /// </summary>
    /// <remarks>
    /// 1. 只能对已购买的商品进行回答，每个问题只能回答一次，并且可以匿名回答。
    /// 2. 允许删除自己发布的回答。
    /// 3. 允许举报别人发布的回答。
    /// 4. 所有已登录的用户都能针对看到的回答，点击是否有用。
    /// 5. 提问者不能回答自己的问题。
    /// 6. 回答一旦发布，回答者只能删除，不能修改。
    /// 7. 回答无需审核。
    /// 8. 提问者可以设置最佳回答，最佳回答将被排序显示到问题回答列表第一行。
    /// </remarks>
    [TableName(Constants.Tables.Answers)]
    [PrimaryKey("Id", AutoIncrement = true)]
    public class Answer : ModelBase
    {
        /// <summary>
        /// 问题标识
        /// </summary>
        public int QuestionId { get; set; }
        /// <summary>
        /// 回答者标识
        /// </summary>
        public int AnswererId { get; set; }
        /// <summary>
        /// 回答者名称
        /// </summary>
        public string AnswererName { get; set; }
        /// <summary>
        /// 回答者头像
        /// </summary>
        public string AnswererAvatar { get; set; }
        /// <summary>
        /// 最佳回答
        /// </summary>
        public bool IsBest { get; set; } = false;
        /// <summary>
        /// 有用数
        /// </summary>
        public int UsefulCount { get; set; }
        /// <summary>
        /// 评论回复数
        /// </summary>
        public int CommentReplyCount { get; set; }
    }
}
