﻿using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Logging;
using Spider.Core;
using System;

namespace Spider
{
    public class SpiderServiceProvider
    {
        public static IServiceProvider GetServiceProvider()
        {
            var env = Environment.GetEnvironmentVariable("DOTNETCORE_ENVIRONMENT");
            if (string.IsNullOrEmpty(env))
                throw new Exception($"Tips: Please firstly set up the application environment[DOTNETCORE_ENVIRONMENT].");

            AppEnvironment.Name = env;

            var config = new ConfigurationBuilder()
                .SetBasePath(AppContext.BaseDirectory)
                .AddJsonFile("appsettings.json")
                .AddJsonFile($"appsettings.{AppEnvironment.Name}.json")
                .Build();

            var container = new ServiceCollection()
                .AddLogging(logging =>
                {
                    logging.AddConfiguration(config.GetSection("Logging"));
                    logging.ClearProviders();
                    logging.AddConsole();
                })
                .AddOptions()
                .AddMemoryCache()
                .AddSingleton<IConfiguration>(config)
                .Configure<MySqlOptions>(config.GetSection(nameof(MySqlOptions)))
                .Configure<DataCollectorOptions>(config.GetSection(nameof(DataCollectorOptions)));

            Bootstrapper.RegisterServices(container);

            return container.BuildInterceptableServiceProvider();
        }
    }
}
